
Encry
------

This is a simple, and fairly insecure Encryption module for python

This is meant to be perfect for Just stuff like chat messages

To use simply type this command once installed
	$ Encry.py --help
Note:
	this command may change (see changelog)

You can the use it as you would a normal command
	$ Encry.py -e test -d
	this meanse encrypt(-e) the message(test) with the default key(-d)
	you can get a randomly generated key with -r
	to decrypt do:
		$ Encry.py --entry 1 -d
		 this means look for entry(1) in output.txt and decrypt it(-d)

You can also use this as a python module, simply type:
	>>>import Encry
	that's it!

better documentation coming soon!

Thank you guys so much for all the downloads!
Please, If you have any bug reports or ideas, Please email me:
shadow889566@gmail.com